@@ -1,9 +1,11 @@
+from __future__ import annotations
+
 import ctypes
 import pickle
 import sys
 import tempfile
 import unittest
-from typing import Dict, Iterator, Tuple
+from typing import Iterator
 
 import numpy as np
 import pytest
@@ -22,10 +24,9 @@ class IndexTestCase(unittest.TestCase):
 
     def boxes15_stream(
         self, interleaved: bool = True
-    ) -> Iterator[Tuple[int, Tuple[float, float, float, float], int]]:
+    ) -> Iterator[tuple[int, tuple[float, float, float, float], int]]:
         boxes15 = np.genfromtxt("boxes_15x15.data")
         for i, (minx, miny, maxx, maxy) in enumerate(boxes15):
-
             if interleaved:
                 yield (i, (minx, miny, maxx, maxy), 42)
             else:
@@ -394,7 +395,7 @@ class IndexSerialization(unittest.TestCase):
 
     def boxes15_stream(
         self, interleaved: bool = True
-    ) -> Iterator[Tuple[int, Tuple[float, float, float, float], int]]:
+    ) -> Iterator[tuple[int, tuple[float, float, float, float], int]]:
         for i, (minx, miny, maxx, maxy) in enumerate(self.boxes15):
             if interleaved:
                 yield (i, (minx, miny, maxx, maxy), 42)
@@ -451,12 +452,13 @@ class IndexSerialization(unittest.TestCase):
         self.assertTrue(len(hits), 10)
         self.assertEqual(hits, [0, 4, 16, 27, 35, 40, 47, 50, 76, 80])
 
+    @pytest.mark.skipif(not sys.maxsize > 2**32, reason="Fails on 32bit systems")
     def test_interleaving(self) -> None:
         """Streaming against a persisted index without interleaving"""
 
         def data_gen(
             interleaved: bool = True,
-        ) -> Iterator[Tuple[int, Tuple[float, float, float, float], int]]:
+        ) -> Iterator[tuple[int, tuple[float, float, float, float], int]]:
             for i, (minx, miny, maxx, maxy) in enumerate(self.boxes15):
                 if interleaved:
                     yield (i, (minx, miny, maxx, maxy), 42)
@@ -588,13 +590,11 @@ class IndexSerialization(unittest.TestCase):
             ),
         ]
 
-        if sys.maxsize > 2**32:
-            # TODO: this fails with CPython 3.7 manylinux i686 i.e. 32-bit
-            # go through the traversal and see if everything is close
-            assert all(
-                all(np.allclose(a, b) for a, b in zip(L, E))
-                for L, E in zip(leaves, expected)
-            )
+        # go through the traversal and see if everything is close
+        assert all(
+            all(np.allclose(a, b) for a, b in zip(L, E))  # type: ignore
+            for L, E in zip(leaves, expected)
+        )
 
         hits2 = sorted(list(idx.intersection((0, 60, 0, 60), objects=True)))
         self.assertTrue(len(hits2), 10)
@@ -726,7 +726,7 @@ class IndexStream(IndexTestCase):
             pass
 
         def create_index() -> index.Index:
-            def gen() -> Iterator[Tuple[int, Tuple[int, int, int, int], None]]:
+            def gen() -> Iterator[tuple[int, tuple[int, int, int, int], None]]:
                 # insert at least 6 or so before the exception
                 for i in range(10):
                     yield (i, (1, 2, 3, 4), None)
@@ -747,7 +747,6 @@ class IndexStream(IndexTestCase):
 
         def create_index() -> index.Index:
             def gen() -> None:
-
                 raise TestException("raising here")
 
             return index.Index(gen())  # type: ignore[func-returns-value]
@@ -770,7 +769,7 @@ class DictStorage(index.CustomStorage):
 
     def clear(self) -> None:
         """Clear all our data"""
-        self.dict: Dict = {}
+        self.dict: dict = {}
 
     def loadByteArray(self, page, returnError):
         """Returns the data for page or returns an error"""
